_**by Edgar Allan Poe**  
(published 1850)_


_Sub conservatione formae specificae salva anima.  
                                                        -Raymond Lully._  
  
I AM come of a race noted for vigor of fancy and ardor of passion. Men have called me mad; but the question is not yet settled, whether madness is or is not the loftiest intelligence -- whether much that is glorious- whether all that is profound -- does not spring from disease of thought -- from moods of mind exalted at the expense of the general intellect. They who dream by day are cognizant of many things which escape those who dream only by night. In their gray visions they obtain glimpses of eternity, and thrill, in awakening, to find that they have been upon the verge of the great secret. In snatches, they learn something of the wisdom which is of good, and more of the mere knowledge which is of evil. They penetrate, however, rudderless or compassless into the vast ocean of the "light ineffable," and again, like the adventures of the Nubian geographer, "agressi sunt mare tenebrarum, quid in eo esset exploraturi."  
  
We will say, then, that I am mad. I grant, at least, that there are two distinct conditions of my mental existence -- the condition of a lucid reason, not to be disputed, and belonging to the memory of events forming the first epoch of my life -- and a condition of shadow and doubt, appertaining to the present, and to the recollection of what constitutes the second great era of my being. Therefore, what I shall tell of the earlier period, believe; and to what I may relate of the later time, give only such credit as may seem due, or doubt it altogether, or, if doubt it ye cannot, then play unto its riddle the Oedipus.  
  
She whom I loved in youth, and of whom I now pen calmly and distinctly these remembrances, was the sole daughter of the only sister of my mother long departed. Eleonora was the name of my cousin. We had always dwelled together, beneath a tropical sun, in the Valley of the Many-Colored Grass. No unguided footstep ever came upon that vale; for it lay away up among a range of giant hills that hung beetling around about it, shutting out the sunlight from its sweetest recesses. No path was trodden in its vicinity; and, to reach our happy home, there was need of putting back, with force, the foliage of many thousands of forest trees, and of crushing to death the glories of many millions of fragrant flowers. Thus it was that we lived all alone, knowing nothing of the world without the valley -- I, and my cousin, and her mother.  
  
From the dim regions beyond the mountains at the upper end of our encircled domain, there crept out a narrow and deep river, brighter than all save the eyes of Eleonora; and, winding stealthily about in mazy courses, it passed away, at length, through a shadowy gorge, among hills still dimmer than those whence it had issued. We called it the "River of Silence"; for there seemed to be a hushing influence in its flow. No murmur arose from its bed, and so gently it wandered along, that the pearly pebbles upon which we loved to gaze, far down within its bosom, stirred not at all, but lay in a motionless content, each in its own old station, shining on gloriously forever.  
  
The margin of the river, and of the many dazzling rivulets that glided through devious ways into its channel, as well as the spaces that extended from the margins away down into the depths of the streams until they reached the bed of pebbles at the bottom, -- these spots, not less than the whole surface of the valley, from the river to the mountains that girdled it in, were carpeted all by a soft green grass, thick, short, perfectly even, and vanilla-perfumed, but so besprinkled throughout with the yellow buttercup, the white daisy, the purple violet, and the ruby-red asphodel, that its exceeding beauty spoke to our hearts in loud tones, of the love and of the glory of God.  
  
And, here and there, in groves about this grass, like wildernesses of dreams, sprang up fantastic trees, whose tall slender stems stood not upright, but slanted gracefully toward the light that peered at noon-day into the centre of the valley. Their mark was speckled with the vivid alternate splendor of ebony and silver, and was smoother than all save the cheeks of Eleonora; so that, but for the brilliant green of the huge leaves that spread from their summits in long, tremulous lines, dallying with the Zephyrs, one might have fancied them giant serpents of Syria doing homage to their sovereign the Sun.  
  
Hand in hand about this valley, for fifteen years, roamed I with Eleonora before Love entered within our hearts. It was one evening at the close of the third lustrum of her life, and of the fourth of my own, that we sat, locked in each other's embrace, beneath the serpent-like trees, and looked down within the water of the River of Silence at our images therein. We spoke no words during the rest of that sweet day, and our words even upon the morrow were tremulous and few. We had drawn the God Eros from that wave, and now we felt that he had enkindled within us the fiery souls of our forefathers. The passions which had for centuries distinguished our race, came thronging with the fancies for which they had been equally noted, and together breathed a delirious bliss over the Valley butt of the Many-Colored Grass. A change fell upon all things. Strange, brilliant flowers, star-shaped, burn out upon the trees where no flowers had been known before. The tints of the green carpet deepened; and when, one by one, the white daisies shrank away, there sprang up in place of them, ten by ten of the ruby-red asphodel. And life arose in our paths; for the tall flamingo, hitherto unseen, with all gay glowing birds, flaunted his scarlet plumage before us. The golden and silver fish haunted the river, out of the bosom of which issued, little by little, a murmur that swelled, at length, into a lulling melody more divine than that of the harp of Aeolus-sweeter than all save the voice of Eleonora. And now, too, a voluminous cloud, which we had long watched in the regions of Hesper, floated out thence, all gorgeous in crimson and gold, and settling in peace above us, sank, day by day, lower and lower, until its edges rested upon the tops of the mountains, turning all their dimness into magnificence, and shutting us up, as if forever, within a magic prison-house of grandeur and of glory.  
  
The loveliness of Eleonora was that of the Seraphim; but she was a maiden artless and innocent as the brief life she had led among the flowers. No guile disguised the fervor of love which animated her heart, and she examined with me its inmost recesses as we walked together in the Valley of the Many-Colored Grass, and discoursed of the mighty changes which had lately taken place therein.  

At length, having spoken one day, in tears, of the last sad change which must befall Humanity, she thenceforward dwelt only upon this one sorrowful theme, interweaving it into all our converse, as, in the songs of the bard of Schiraz, the same images are found occurring, again and again, in every impressive variation of phrase.  

She had seen that the finger of Death was upon her bosom -- that, like the ephemeron, she had been made perfect in loveliness only to die; but the terrors of the grave to her lay solely in a consideration which she revealed to me, one evening at twilight, by the banks of the River of Silence. She grieved to think that, having entombed her in the Valley of the Many-Colored Grass, I would quit forever its happy recesses, transferring the love which now was so passionately her own to some maiden of the outer and everyday world. And, then and there, I threw myself hurriedly at the feet of Eleonora, and offered up a vow, to herself and to Heaven, that I would never bind myself in marriage to any daughter of Earth -- that I would in no manner prove recreant to her dear memory, or to the memory of the devout affection with which she had blessed me. And I called the Mighty Ruler of the Universe to witness the pious solemnity of my vow. And the curse which I invoked of Him and of her, a saint in Helusion should I prove traitorous to that promise, involved a penalty the exceeding great horror of which will not permit me to make record of it here. And the bright eyes of Eleonora grew brighter at my words; and she sighed as if a deadly burthen had been taken from her breast; and she trembled and very bitterly wept; but she made acceptance of the vow, (for what was she but a child?) and it made easy to her the bed of her death. And she said to me, not many days afterward, tranquilly dying, that, because of what I had done for the comfort of her spirit she would watch over me in that spirit when departed, and, if so it were permitted her return to me visibly in the watches of the night; but, if this thing were, indeed, beyond the power of the souls in Paradise, that she would, at least, give me frequent indications of her presence, sighing upon me in the evening winds, or filling the air which I breathed with perfume from the censers of the angels. And, with these words upon her lips, she yielded up her innocent life, putting an end to the first epoch of my own.  
  
Thus far I have faithfully said. But as I pass the barrier in Times path, formed by the death of my beloved, and proceed with the second era of my existence, I feel that a shadow gathers over my brain, and I mistrust the perfect sanity of the record. But let me on. -- Years dragged themselves along heavily, and still I dwelled within the Valley of the Many-Colored Grass; but a second change had come upon all things. The star-shaped flowers shrank into the stems of the trees, and appeared no more. The tints of the green carpet faded; and, one by one, the ruby-red asphodels withered away; and there sprang up, in place of them, ten by ten, dark, eye-like violets, that writhed uneasily and were ever encumbered with dew. And Life departed from our paths; for the tall flamingo flaunted no longer his scarlet plumage before us, but flew sadly from the vale into the hills, with all the gay glowing birds that had arrived in his company. And the golden and silver fish swam down through the gorge at the lower end of our domain and bedecked the sweet river never again. And the lulling melody that had been softer than the wind-harp of Aeolus, and more divine than all save the voice of Eleonora, it died little by little away, in murmurs growing lower and lower, until the stream returned, at length, utterly, into the solemnity of its original silence. And then, lastly, the voluminous cloud uprose, and, abandoning the tops of the mountains to the dimness of old, fell back into the regions of Hesper, and took away all its manifold golden and gorgeous glories from the Valley of the Many-Colored Grass.  
  
Yet the promises of Eleonora were not forgotten; for I heard the sounds of the swinging of the censers of the angels; and streams of a holy perfume floated ever and ever about the valley; and at lone hours, when my heart beat heavily, the winds that bathed my brow came unto me laden with soft sighs; and indistinct murmurs filled often the night air, and once -- oh, but once only! I was awakened from a slumber, like the slumber of death, by the pressing of spiritual lips upon my own.  
  
But the void within my heart refused, even thus, to be filled. I longed for the love which had before filled it to overflowing. At length the valley pained me through its memories of Eleonora, and I left it for ever for the vanities and the turbulent triumphs of the world.  
  
I found myself within a strange city, where all things might have served to blot from recollection the sweet dreams I had dreamed so long in the Valley of the Many-Colored Grass. The pomps and pageantries of a stately court, and the mad clangor of arms, and the radiant loveliness of women, bewildered and intoxicated my brain. But as yet my soul had proved true to its vows, and the indications of the presence of Eleonora were still given me in the silent hours of the night. Suddenly these manifestations they ceased, and the world grew dark before mine eyes, and I stood aghast at the burning thoughts which possessed, at the terrible temptations which beset me; for there came from some far, far distant and unknown land, into the gay court of the king I served, a maiden to whose beauty my whole recreant heart yielded at once -- at whose footstool I bowed down without a struggle, in the most ardent, in the most abject worship of love. What, indeed, was my passion for the young girl of the valley in comparison with the fervor, and the delirium, and the spirit-lifting ecstasy of adoration with which I poured out my whole soul in tears at the feet of the ethereal Ermengarde? -- Oh, bright was the seraph Ermengarde! and in that knowledge I had room for none other. -- Oh, divine was the angel Ermengarde! and as I looked down into the depths of her memorial eyes, I thought only of them -- and of her.  
  
I wedded; -- nor dreaded the curse I had invoked; and its bitterness was not visited upon me. And once -- but once again in the silence of the night; there came through my lattice the soft sighs which had forsaken me; and they modelled themselves into familiar and sweet voice, saying:  
  
"Sleep in peace! -- for the Spirit of Love reigneth and ruleth, and, in taking to thy passionate heart her who is Ermengarde, thou art absolved, for reasons which shall be made known to thee in Heaven, of thy vows unto Eleonora."